@@ -103,7 +103,7 @@ func (m *Manager) handleFilePasswdChanged() {
 			u.updatePropsPasswd(uInfo)
 		} else {
 			// 域账户没有保存在本地，无需删除
-			if !m.isUdcpUserID(u.Uid) {
+			if !m.isDomainUser(u.Uid) {
 				uidsDelete = append(uidsDelete, u.Uid)
 			}
 		}
@@ -151,10 +151,42 @@ func (m *Manager) updatePropUserList() {
 func (m *Manager) handleFileGroupChanged() {
 	m.usersMapMu.Lock()
 	defer m.usersMapMu.Unlock()
+	accountType := int32(users.UserTypeStandard)
+	var groups []string
+	var err error
+
 	for _, u := range m.usersMap {
-		u.updatePropAccountType()
+		// 由于域用户的组信息没有保存在/etc/group文件中，因此，在/etc/group更新时，更新下域用户的组和账户类型
+		if m.isUdcpUserID(u.Uid) {
+			if m.udcpCache == nil {
+				logger.Warning("handleFileGroupChanged m.udcpCache is nil.")
+				return
+			}
+			groups, err := m.udcpCache.GetUserGroups(0, u.UserName)
+			if err != nil {
+				logger.Warningf("Udcp cache getUserGroups failed: %v", err)
+				continue
+			}
+
+			if strv.Strv(groups).Contains("sudo") {
+				accountType = users.UserTypeAdmin
+			}
+		} else if users.IsLDAPDomainUserID(u.Uid) {
+			id, _ := strconv.Atoi(u.Uid)
+			groups, err = users.GetADUserGroupsByUID(uint32(id))
+			accountType = users.UserTypeStandard
+			if err != nil {
+				logger.Warningf("get domain user groups failed: %v", err)
+				continue
+			}
+		} else {
+			accountType = u.getAccountType()
+			groups = u.getGroups()
+		}
+
+		u.updatePropAccountType(accountType)
 		u.updatePropCanNoPasswdLogin()
-		u.updatePropGroups()
+		u.updatePropGroups(groups)
 	}
 }
 
@@ -189,8 +221,8 @@ func (m *Manager) addUser(uInfo *users.UserInfo) {
 	}
 }
 
-func (m *Manager) addUdcpUser(uId uint32) error {
-	logger.Debug("addUdcpUser", uId)
+func (m *Manager) addDomainUser(uId uint32) error {
+	logger.Debug("addDomainUser", uId)
 	udcpUId := strconv.FormatUint(uint64(uId), 10)
 	err := m.exportUserByUid(udcpUId)
 	if err != nil {
@@ -205,6 +237,24 @@ func (m *Manager) addUdcpUser(uId uint32) error {
 	return err
 }
 
+func (m *Manager) isDomainUser(uid string) bool {
+	return m.isUdcpUserID(uid) || users.IsLDAPDomainUserID(uid)
+}
+
+func (m *Manager) isUdcpUserExists(name string) bool {
+	if m.udcpCache == nil {
+		logger.Warning("isUdcpUserExists m.udcpCache is nil.")
+		return false
+	}
+	_, err := m.udcpCache.GetUserGroups(0, name)
+	if err != nil {
+		logger.Warningf("Udcp cache getUserGroups failed: %v", err)
+		return false
+	}
+
+	return true
+}
+
 // 判断用户缓存UID列表中是否有域账户，域账户信息只能由web端设置，本地没有保存。
 // 因此，本地/etc/passwd更新不能删除域账户服务
 func (m *Manager) isUdcpUserID(uid string) bool {
@@ -241,6 +291,10 @@ func (m *Manager) deleteUser(uid string) {
 		logger.Warningf("uid %s not found", uid)
 	}
 
+	if users.IsAutoLoginUser(user.UserName) {
+		_ = users.SetAutoLoginUser("", "")
+	}
+
 	userPath := userDBusPathPrefix + uid
 	m.stopExportUser(userPath)
 	err := m.service.Emit(m, "UserDeleted", userPath)
