@@ -175,7 +175,7 @@ func NewUser(userPath string, service *dbusutil.Service, ignoreErr bool) (*User,
 	return u, nil
 }
 
-func NewUdcpUser(usrId uint32, service *dbusutil.Service, groups []string) (*User, error) {
+func NewDomainUser(usrId uint32, service *dbusutil.Service, groups []string) (*User, error) {
 	var err error
 	if users.ExistPwUid(usrId) != 0 {
 		return nil, errors.New("no such user id")
@@ -199,6 +199,7 @@ func NewUdcpUser(usrId uint32, service *dbusutil.Service, groups []string) (*Use
 		PasswordLastChange: 18737,
 	}
 
+	u.AccountType = users.UserTypeDomain
 	u.Groups = groups
 
 	// 解析对应域管用户是否有添加到sudo组里面，有为管理员用户，否则为标准用户
@@ -353,10 +354,9 @@ func (u *User) writeUserConfig() error {
 	return u.writeUserConfigWithChanges(nil)
 }
 
-func (u *User) updatePropAccountType() {
-	newVal := u.getAccountType()
+func (u *User) updatePropAccountType(accountType int32) {
 	u.PropsMu.Lock()
-	u.setPropAccountType(newVal)
+	u.setPropAccountType(accountType)
 	u.PropsMu.Unlock()
 }
 
@@ -367,10 +367,9 @@ func (u *User) updatePropCanNoPasswdLogin() {
 	u.PropsMu.Unlock()
 }
 
-func (u *User) updatePropGroups() {
-	newVal := u.getGroups()
+func (u *User) updatePropGroups(groups []string) {
 	u.PropsMu.Lock()
-	u.setPropGroups(newVal)
+	u.setPropGroups(groups)
 	u.PropsMu.Unlock()
 }
 
