@@ -220,9 +220,14 @@ func (u *User) SetMaxPasswordAge(sender dbus.Sender, nDays int32) *dbus.Error {
 	return nil
 }
 
-func (u *User) IsPasswordExpired() (expired bool, busErr *dbus.Error) {
-	expired, err := users.IsPasswordExpired(u.UserName)
-	return expired, dbusutil.ToError(err)
+func (u *User) IsPasswordExpired() (bool, *dbus.Error) {
+	// LDAP 域用户密码由域服务器控制，系统不去做密码过期检测
+	if users.IsLDAPDomainUserID(u.Uid) {
+		return false, nil
+	}
+
+	v, err := users.IsPasswordExpired(u.UserName)
+	return v, dbusutil.ToError(err)
 }
 
 func (u *User) SetLocked(sender dbus.Sender, locked bool) *dbus.Error {
@@ -1008,12 +1013,13 @@ func (u *User) PasswordExpiredInfo() (expiredStatus ExpiredStatus, dayLeft int64
 	curDays := time.Now().Unix() / secondsPerDay
 	daysLeft := spLastChg + spMax - curDays
 
+	// daysLeft < 0时为已经过期，等于0时即当天过期时按1天算，因此大于等于0时需要加1天
 	if daysLeft < 0 {
 		return expiredStatusExpiredAlready, daysLeft, nil
 	} else if spWarn > daysLeft {
-		return expiredStatusExpiredSoon, daysLeft, nil
+		return expiredStatusExpiredSoon, daysLeft + 1, nil
 	}
-	return expiredStatusNormal, daysLeft, nil
+	return expiredStatusNormal, daysLeft + 1, nil
 }
 
 func (u *User) SetPasswordHint(hint string) (busErr *dbus.Error) {
