@@ -15,6 +15,7 @@ import (
 	"os"
 	"regexp"
 	"strings"
+	"sync"
 	"unsafe"
 
 	"github.com/linuxdeepin/go-lib/strv"
@@ -33,6 +34,16 @@ var (
 	langReg = regexp.MustCompile("_")
 )
 
+type fontOverrideProp struct {
+	AppendLang []string
+}
+type IrregularFontOverrideMap map[string]*fontOverrideProp
+
+var (
+	_irregularFontOverrideMap   IrregularFontOverrideMap
+	_irregularFontOverrideMapMu sync.Mutex
+)
+
 var familyBlacklist = strv.Strv([]string{
 	// font family names of Deepin Open Symbol Fonts:
 	"Symbol",
@@ -149,9 +160,14 @@ func fcInfoToFamily(cInfo *C.FcInfo) *Family {
 	if familyBlacklist.Contains(family) {
 		return nil
 	}
-
 	// info.Deletable = isDeletable(info.File)
 	langs := strings.Split(C.GoString(cInfo.lang), defaultLangDelim)
+	_irregularFontOverrideMapMu.Lock()
+	overrideProp, ok := _irregularFontOverrideMap[family]
+	if ok {
+		langs = append(langs, overrideProp.AppendLang...)
+	}
+	_irregularFontOverrideMapMu.Unlock()
 	return &Family{
 		Id:        family,
 		Name:      getItemByIndex(indexOf(getCurLang(), familyLang), families),
@@ -233,3 +249,9 @@ func getLangFromLocale(locale string) string {
 	}
 	return lang
 }
+
+func SetIrregularFontWhiteList(overrideMap IrregularFontOverrideMap) {
+	_irregularFontOverrideMapMu.Lock()
+	_irregularFontOverrideMap = overrideMap
+	_irregularFontOverrideMapMu.Unlock()
+}
