@@ -24,18 +24,13 @@ import (
 	"github.com/fsnotify/fsnotify"
 	dbus "github.com/godbus/dbus"
 	"github.com/linuxdeepin/dde-api/theme_thumb"
-	"github.com/linuxdeepin/dde-daemon/appearance/background"
-	"github.com/linuxdeepin/dde-daemon/appearance/fonts"
-	"github.com/linuxdeepin/dde-daemon/appearance/subthemes"
-	"github.com/linuxdeepin/dde-daemon/common/dsync"
-	ddbus "github.com/linuxdeepin/dde-daemon/dbus"
-	"github.com/linuxdeepin/dde-daemon/session/common"
 	accounts "github.com/linuxdeepin/go-dbus-factory/com.deepin.daemon.accounts"
 	display "github.com/linuxdeepin/go-dbus-factory/com.deepin.daemon.display"
 	imageeffect "github.com/linuxdeepin/go-dbus-factory/com.deepin.daemon.imageeffect"
 	sessiontimedate "github.com/linuxdeepin/go-dbus-factory/com.deepin.daemon.timedate"
 	sessionmanager "github.com/linuxdeepin/go-dbus-factory/com.deepin.sessionmanager"
 	wm "github.com/linuxdeepin/go-dbus-factory/com.deepin.wm"
+	configManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
 	login1 "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.login1"
 	timedate "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.timedate1"
 	gio "github.com/linuxdeepin/go-gir/gio-2.0"
@@ -48,6 +43,13 @@ import (
 	"github.com/linuxdeepin/go-lib/xdg/basedir"
 	x "github.com/linuxdeepin/go-x11-client"
 	"github.com/linuxdeepin/go-x11-client/ext/randr"
+
+	"github.com/linuxdeepin/dde-daemon/appearance/background"
+	"github.com/linuxdeepin/dde-daemon/appearance/fonts"
+	"github.com/linuxdeepin/dde-daemon/appearance/subthemes"
+	"github.com/linuxdeepin/dde-daemon/common/dsync"
+	ddbus "github.com/linuxdeepin/dde-daemon/dbus"
+	"github.com/linuxdeepin/dde-daemon/session/common"
 )
 
 //go:generate dbusutil-gen em -type Manager
@@ -103,6 +105,13 @@ const (
 	dbusInterface   = dbusServiceName
 )
 
+// TODO 后续需要设计成用 subpath + 独立的 dconfig 配置来实现,增加可读性
+const (
+	dsettingsAppID                    = "org.deepin.dde.daemon"
+	dsettingsAppearanceName           = "org.deepin.dde.daemon.appearance"
+	dsettingsIrregularFontOverrideKey = "irregularFontOverride"
+)
+
 var wsConfigFile = filepath.Join(basedir.GetUserConfigDir(), "deepin/dde-daemon/appearance/wallpaper-slideshow.json")
 
 // Manager shows current themes and fonts settings, emit 'Changed' signal if modified
@@ -616,6 +625,9 @@ func (m *Manager) init() error {
 		logger.Warning("failed to set cursor theme:", err)
 	}
 
+	// Init IrregularFontWhiteList
+	m.initAppearanceDSettings()
+
 	// Init theme list
 	time.AfterFunc(time.Second*10, func() {
 		if !dutils.IsFileExist(fonts.DeepinFontConfig) {
@@ -1541,21 +1553,43 @@ func (m *Manager) updateNewVersionData() error {
 		}
 	}
 
-	// V20对应SP3, SP2阶段gsettings background-uris中部分数据丢失，SP2升到SP3通过窗管接口获取壁纸
 	monitorWorkspaceWallpaperURIs := make(mapMonitorWorkspaceWallpaperURIs)
-	for monitorName, convertMonitorName := range m.monitorMap {
-		for i := int32(0); i < workspaceCount; i++ {
-			uri, err := m.wm.GetWorkspaceBackgroundForMonitor(0, i+1, monitorName)
-			if err != nil {
-				logger.Warningf("failed to get monitor:%v workspace:%v background:%v", monitorName, i+1, err)
-				continue
-			}
-
-			key := genMonitorKeyString(convertMonitorName, i+1)
-			monitorWorkspaceWallpaperURIs[key] = uri
+	backgroundURIs := m.getBackgroundURIs()
+	for i, uri := range backgroundURIs {
+		err := m.wm.SetWorkspaceBackgroundForMonitor(0, int32(i+1), primaryMonitor, uri)
+		if err != nil {
+			return fmt.Errorf("failed to set background:%v to workspace%v : %v", uri, i+1, err)
 		}
+		key := genMonitorKeyString("Primary", i+1)
+		monitorWorkspaceWallpaperURIs[key] = uri
 	}
-	return m.setPropertyWallpaperURIs(monitorWorkspaceWallpaperURIs)
+	err = m.setPropertyWallpaperURIs(monitorWorkspaceWallpaperURIs)
+	if err != nil {
+		return err
+	}
+
+	go func() {
+		// V20对应SP3, SP2阶段gsettings background-uris中部分数据丢失，SP2升到SP3通过窗管接口获取壁纸
+		// 目前第一次初始化，wm和appearance存在互相依赖，因此这里同步wm数据只能异步，这属于设计问题，后续可以优化交互逻辑
+		monitorWorkspaceWallpaperURIs := make(mapMonitorWorkspaceWallpaperURIs)
+		for monitorName, convertMonitorName := range m.monitorMap {
+			for i := int32(0); i < workspaceCount; i++ {
+				uri, err := m.wm.GetWorkspaceBackgroundForMonitor(0, i+1, monitorName)
+				if err != nil {
+					logger.Warningf("failed to get monitor:%v workspace:%v background:%v", monitorName, i+1, err)
+					continue
+				}
+
+				key := genMonitorKeyString(convertMonitorName, i+1)
+				monitorWorkspaceWallpaperURIs[key] = uri
+			}
+		}
+		err := m.setPropertyWallpaperURIs(monitorWorkspaceWallpaperURIs)
+		if err != nil {
+			logger.Warning("failed to set wallpaper:", err)
+		}
+	}()
+	return nil
 }
 
 func genMonitorKeyString(monitor string, idx interface{}) string {
@@ -1612,3 +1646,47 @@ func (m *Manager) iso6709Parsing(city, coordinates string) {
 	cdn.latitude = lat
 	m.coordinateMap[city] = &cdn
 }
+
+func (m *Manager) initAppearanceDSettings() {
+	ds := configManager.NewConfigManager(m.sysSigLoop.Conn())
+
+	appearancePath, err := ds.AcquireManager(0, dsettingsAppID, dsettingsAppearanceName, "")
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	dsAppearance, err := configManager.NewManager(m.sysSigLoop.Conn(), appearancePath)
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	getIrregularFontWhiteListKey := func() {
+		v, err := dsAppearance.Value(0, dsettingsIrregularFontOverrideKey)
+		if err != nil {
+			logger.Warning(err)
+			return
+		}
+		var overrideMap fonts.IrregularFontOverrideMap
+		overrideMapString := v.Value().(string)
+		err = json.Unmarshal([]byte(overrideMapString), &overrideMap)
+		if err != nil {
+			logger.Warning(err)
+			return
+		}
+		fonts.SetIrregularFontWhiteList(overrideMap)
+	}
+
+	getIrregularFontWhiteListKey()
+
+	dsAppearance.InitSignalExt(m.sysSigLoop, true)
+	_, err = dsAppearance.ConnectValueChanged(func(key string) {
+		if key == dsettingsIrregularFontOverrideKey {
+			getIrregularFontWhiteListKey()
+		}
+	})
+	if err != nil {
+		logger.Warning(err)
+	}
+}
