@@ -33,7 +33,9 @@ func (m *Manager) registerIdentifyWindowFuncs() {
 	m.registerIdentifyWindowFunc("FlatpakAppID", identifyWindowByFlatpakAppID)
 	m.registerIdentifyWindowFunc("CrxId", identifyWindowByCrxId)
 	m.registerIdentifyWindowFunc("Rule", identifyWindowByRule)
-	m.registerIdentifyWindowFunc("Bamf", identifyWindowByBamf)
+	m.registerIdentifyWindowFunc("Bamf", func(m *Manager, winInfo *WindowInfo) (string, *AppInfo) {
+		return identifyWindowByBamf(m, &winInfo.baseWindowInfo)
+	})
 	m.registerIdentifyWindowFunc("Pid", identifyWindowByPid)
 	m.registerIdentifyWindowFunc("Scratch", identifyWindowByScratch)
 	m.registerIdentifyWindowFunc("GtkAppId", identifyWindowByGtkAppId)
@@ -47,6 +49,31 @@ func (m *Manager) registerIdentifyWindowFunc(name string, fn _IdentifyWindowFunc
 	})
 }
 
+type IdentifyKWindowFunc struct {
+	Name string
+	Fn   _IdentifyKWindowFunc
+}
+
+type _IdentifyKWindowFunc func(*Manager, *KWindowInfo) (string, *AppInfo)
+
+func (m *Manager) registerIdentifyKWindowFuncs() {
+	m.registerIdentifyKWindowFunc("PidEnv", func(m *Manager, winInfo *KWindowInfo) (string, *AppInfo) {
+		return identifyWindowByPidEnv(m, &winInfo.baseWindowInfo)
+	})
+	m.registerIdentifyKWindowFunc("ExeEnv", identifyKwindowByExeEnv)
+	m.registerIdentifyKWindowFunc("WmClass", identifyKWindowByWMClass)
+	m.registerIdentifyKWindowFunc("Bamf", func(m *Manager, winInfo *KWindowInfo) (string, *AppInfo) {
+		return identifyWindowByBamf(m, &winInfo.baseWindowInfo)
+	})
+}
+
+func (m *Manager) registerIdentifyKWindowFunc(name string, fn _IdentifyKWindowFunc) {
+	m.identifyKWindowFuns = append(m.identifyKWindowFuns, &IdentifyKWindowFunc{
+		Name: name,
+		Fn:   fn,
+	})
+}
+
 func (m *Manager) identifyWindow(winInfo WindowInfoImp) (innerId string, appInfo *AppInfo) {
 	switch winType := winInfo.(type) {
 	case *WindowInfo:
@@ -58,6 +85,37 @@ func (m *Manager) identifyWindow(winInfo WindowInfoImp) (innerId string, appInfo
 	}
 }
 
+func identifyKWindowByWMClass(m *Manager, winInfo *KWindowInfo) (innerId string, appInfo *AppInfo) {
+	wmClass, _ := getWmClass(winInfo.xid)
+	if wmClass != nil {
+		instance := wmClass.Instance
+		if instance != "" {
+			appInfo = NewAppInfo("org.deepin.flatdeb." + strings.ToLower(instance))
+			if appInfo != nil {
+				innerId = appInfo.innerId
+				return
+			}
+
+			appInfo = NewAppInfo(instance)
+			if appInfo != nil {
+				innerId = appInfo.innerId
+				return
+			}
+		}
+
+		class := wmClass.Class
+		if class != "" {
+			appInfo = NewAppInfo(class)
+			if appInfo != nil {
+				innerId = appInfo.innerId
+				return
+			}
+		}
+	}
+
+	return
+}
+
 func (m *Manager) identifyWindowK(winInfo *KWindowInfo) (innerId string, appInfo *AppInfo) {
 	// TODO: 对桌面调起的文管应用做规避处理，需要在此处添加，因为初始化时appId和title为空
 	if winInfo.appId == "dde-desktop" && m.shouldShowOnDock(winInfo) {
@@ -69,69 +127,64 @@ func (m *Manager) identifyWindowK(winInfo *KWindowInfo) (innerId string, appInfo
 	if title == "下载" {
 		appId = "uos-browser"
 	}
-	// 先使用appId获取appInfo,如果不能成功获取再使用pidenv环境变量获取
-	appInfo = NewAppInfo(appId)
-	if appInfo == nil {
-		// 防止出现指针为空调用后崩溃问题
+
+	// wayland环境下，如果是Wine应用（微信，企业微信等），appId为wine，根据进程环境变量去需要获取具体应用的appId
+	if appId == "wine" {
 		if winInfo.process != nil {
-			_, appInfo = identifyWindowByPidEnv(m, &winInfo.baseWindowInfo)
+			launchedDesktopFile := winInfo.process.environ.Get("GIO_LAUNCHED_DESKTOP_FILE")
+			logger.Debugf("%s launchedDesktopFile: %s", appId, launchedDesktopFile)
+
+			parts := strings.Split(launchedDesktopFile, "/")
+			partsLen := len(parts)
+			if partsLen >= 1 {
+				appId = parts[partsLen-1]
+				logger.Debugf("identifyWindowK: actual wine application appid: %s", appId)
+			}
 		}
 	}
 
-	if appInfo != nil {
+	// 先使用appId获取appInfo,如果不能成功再通过定义的识别窗口机制去识别
+	appInfo = NewAppInfo(appId)
+	if appInfo == nil {
+		for idx, item := range m.identifyKWindowFuns {
+			name := item.Name
+			logger.Debugf("identifyWindowK: try %s:%d", name, idx)
+			innerId, appInfo = item.Fn(m, winInfo)
+			if innerId != "" {
+				// success
+				logger.Debugf("identifyWindowK by %s success, innerId: %q, appInfo: %v",
+					name, innerId, appInfo)
+
+				// NOTE: if name == "Pid", appInfo may be nil
+				if appInfo != nil {
+					fixedAppInfo := fixAutostartAppInfo(appInfo)
+					if fixedAppInfo != nil {
+						appInfo = fixedAppInfo
+						appInfo.identifyMethod = name + "+FixAutostart"
+						innerId = fixedAppInfo.innerId
+					} else {
+						appInfo.identifyMethod = name
+					}
+				}
+				return
+			}
+		}
+	} else {
 		innerId = appInfo.innerId
 		fixedAppInfo := fixAutostartAppInfo(appInfo)
 		if fixedAppInfo != nil {
 			appInfo = fixedAppInfo
 			appInfo.identifyMethod = "FixAutostart"
 			innerId = fixedAppInfo.innerId
-			return
-		}
-	} else {
-		// bamf
-		win := winInfo.xid
-		desktop, err := getDesktopFromWindowByBamf(win)
-		if err != nil {
-			logger.Warning(err)
-			return
 		}
 
-		if desktop != "" {
-			appInfo = NewAppInfoFromFile(desktop)
-			if appInfo != nil {
-				// success
-				innerId = appInfo.innerId
-				return
-			}
-		}
-
-		wmClass, _ := getWmClass(win)
-		if wmClass != nil {
-			instance := wmClass.Instance
-			if instance != "" {
-				appInfo = NewAppInfo("org.deepin.flatdeb." + strings.ToLower(instance))
-				if appInfo != nil {
-					innerId = appInfo.innerId
-					return
-				}
-
-				appInfo = NewAppInfo(instance)
-				if appInfo != nil {
-					innerId = appInfo.innerId
-					return
-				}
-			}
-
-			class := wmClass.Class
-			if class != "" {
-				appInfo = NewAppInfo(class)
-				if appInfo != nil {
-					innerId = appInfo.innerId
-					return
-				}
-			}
-		}
+		logger.Debugf("identifyWindowK by %s success, innerId: %q, appInfo: %v",
+			"AppId", innerId, appInfo)
+		return
 	}
+
+	// fail
+	logger.Debugf("identifyWindowK: failed")
 	return
 }
 
@@ -149,8 +202,8 @@ func (m *Manager) identifyWindowX(winInfo *WindowInfo) (innerId string, appInfo
 		innerId, appInfo = item.Fn(m, winInfo)
 		if innerId != "" {
 			// success
-			logger.Debugf("identifyWindow by %s success, innerId: %q, appInfo: %v",
-				name, innerId, appInfo)
+			logger.Debugf("identifyWindow by %s success, innerId: %q",
+				name, innerId)
 			// NOTE: if name == "Pid", appInfo may be nil
 			if appInfo != nil {
 				fixedAppInfo := fixAutostartAppInfo(appInfo)
@@ -406,6 +459,26 @@ func identifyWindowByPidEnv(m *Manager, winInfo *baseWindowInfo) (string, *AppIn
 	return "", nil
 }
 
+func identifyKwindowByExeEnv(m *Manager, winInfo *KWindowInfo) (string, *AppInfo) {
+	appId := winInfo.appId
+	msgPrefix := fmt.Sprintf("identifyKwindowByExeEnv appId: %s ", appId)
+	process := winInfo.process
+	customExecName := filepath.Base(process.exe)
+
+	// 对于一个应用对应多个pid的情况，根据process中的可执行文件名和该应用的appId去识别窗口
+	if strings.Contains(customExecName, appId) {
+		launchedDesktopFile := process.environ.Get("GIO_LAUNCHED_DESKTOP_FILE")
+		logger.Debug(msgPrefix, "launchedDesktopFile: ", launchedDesktopFile)
+		appInfo := NewAppInfoFromFile(launchedDesktopFile)
+		if appInfo != nil {
+			// success
+			return appInfo.innerId, appInfo
+		}
+	}
+
+	return "", nil
+}
+
 func identifyWindowByRule(m *Manager, winInfo *WindowInfo) (string, *AppInfo) {
 	msgPrefix := fmt.Sprintf("identifyWindowByRule win: %d ", winInfo.xid)
 	ret := m.windowPatterns.Match(winInfo)
@@ -467,7 +540,7 @@ func identifyWindowByWmClass(m *Manager, winInfo *WindowInfo) (string, *AppInfo)
 	return "", nil
 }
 
-func identifyWindowByBamf(m *Manager, winInfo *WindowInfo) (string, *AppInfo) {
+func identifyWindowByBamf(m *Manager, winInfo *baseWindowInfo) (string, *AppInfo) {
 	msgPrefix := fmt.Sprintf("identifyWindowByBamf win: %d ", winInfo.xid)
 	win := winInfo.xid
 	desktop := ""
