@@ -22,7 +22,9 @@ import (
 	shutdownfront "github.com/linuxdeepin/go-dbus-factory/com.deepin.dde.shutdownfront"
 	sessionmanager "github.com/linuxdeepin/go-dbus-factory/com.deepin.sessionmanager"
 	power "github.com/linuxdeepin/go-dbus-factory/com.deepin.system.power"
+	systeminfo "github.com/linuxdeepin/go-dbus-factory/com.deepin.system.systeminfo"
 	wm "github.com/linuxdeepin/go-dbus-factory/com.deepin.wm"
+	configManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
 	login1 "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.login1"
 	gio "github.com/linuxdeepin/go-gir/gio-2.0"
 	"github.com/linuxdeepin/go-lib/dbusutil"
@@ -60,8 +62,13 @@ const (
 	CapslockKey      = 58
 	NumlockKey       = 69
 	KeyPress         = 1
+)
 
-	configManagerId = "org.desktopspec.ConfigManager"
+const (
+	DSettingsAppID                    = "org.deepin.dde.daemon"
+	DSettingsKeyBindingName           = "org.deepin.dde.daemon.keybinding"
+	DSettingsKeyWirelessControlEnable = "wirelessControlEnable"
+	DSettingsKeyNeedXrandrQDevices    = "need-xrandr-q-devices"
 )
 
 const ( // power按键事件的响应
@@ -97,7 +104,6 @@ type Manager struct {
 
 	enableListenGSettings   bool
 	delayNetworkStateChange bool
-	dpmsIsOff               bool
 	clickNum                uint32
 	shortcutCmd             string
 	shortcutKey             string
@@ -142,9 +148,12 @@ type Manager struct {
 
 	// dsg config
 	wifiControlEnable bool
+	needXrandrQDevice []string
 
 	configManagerPath dbus.ObjectPath
 
+	dmiInfo systeminfo.DMIInfo
+
 	//nolint
 	signals *struct {
 		Added, Deleted, Changed struct {
@@ -196,23 +205,6 @@ func newManager(service *dbusutil.Service) (*Manager, error) {
 		m.login1Manager = login1.NewManager(sysBus)
 	}
 
-	// 加载dsg配置
-	systemConnObj := sysBus.Object(configManagerId, "/")
-	err = systemConnObj.Call(configManagerId+".acquireManager", 0, "org.deepin.dde.daemon", "org.deepin.dde.daemon.keybinding", "").Store(&m.configManagerPath)
-	if err != nil {
-		logger.Warning(err)
-	}
-
-	err = dbusutil.NewMatchRuleBuilder().Type("signal").
-		PathNamespace(string(m.configManagerPath)).
-		Interface("org.desktopspec.ConfigManager.Manager").
-		Member("valueChanged").Build().AddTo(sysBus)
-	if err != nil {
-		logger.Warning(err)
-	}
-
-	m.wifiControlEnable = m.getwirelessControlEnable()
-
 	m.init()
 
 	m.gsKeyboard = gio.NewSettings(gsSchemaKeyboard)
@@ -222,7 +214,7 @@ func newManager(service *dbusutil.Service) (*Manager, error) {
 	m.systemSigLoop.Start()
 
 	m.initNumLockState(sysBus)
-
+	m.initDSettings(sysBus)
 	return &m, nil
 }
 
@@ -230,7 +222,6 @@ func (m *Manager) init() {
 	sessionBus := m.service.Conn()
 	sysBus, _ := dbus.SystemBus()
 	m.delayNetworkStateChange = true
-	m.dpmsIsOff = false
 
 	// init settings
 	m.gsSystem = gio.NewSettings(gsSchemaSystem)
@@ -312,7 +303,7 @@ func (m *Manager) init() {
 		logger.Warning("connect CurrentLayout property changed failed:", err)
 	}
 
-	m.displayController = NewDisplayController(m.backlightHelper, sessionBus)
+	m.displayController = NewDisplayController(m.backlightHelper, sessionBus, m)
 	m.kbdLightController = NewKbdLightController(m.backlightHelper)
 	m.touchPadController = NewTouchPadController(sessionBus)
 
@@ -323,13 +314,72 @@ func (m *Manager) init() {
 		logger.Warning(err)
 	}
 
+	sysInfo := systeminfo.NewSystemInfo(sysBus)
+	dmiInfo, err := sysInfo.DMIInfo().Get(0)
+	if err != nil {
+		logger.Warning(err)
+	} else {
+		m.dmiInfo = dmiInfo
+	}
+
 	if _useWayland {
 		m.initHandlers()
 		m.clickNum = 0
 
 		go m.listenGlobalAccel(sessionBus)
 		go m.listenKeyboardEvent(sysBus)
-		go m.listenMouseEvent(sysBus)
+	}
+}
+
+func (m *Manager) initDSettings(bus *dbus.Conn) {
+	ds := configManager.NewConfigManager(bus)
+	dsPath, err := ds.AcquireManager(0, DSettingsAppID, DSettingsKeyBindingName, "")
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	keybindingDS, err := configManager.NewManager(bus, dsPath)
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	getWirelessControlEnableConfig := func() {
+		v, err := keybindingDS.Value(0, DSettingsKeyWirelessControlEnable)
+		if err != nil {
+			logger.Warning(err)
+			return
+		}
+		m.wifiControlEnable = v.Value().(bool)
+	}
+	getNeedXrandrQConfig := func() {
+		v, err := keybindingDS.Value(0, DSettingsKeyNeedXrandrQDevices)
+		if err != nil {
+			logger.Warning(err)
+			return
+		}
+		itemList := v.Value().([]dbus.Variant)
+		for _, i := range itemList {
+			m.needXrandrQDevice = append(m.needXrandrQDevice, i.Value().(string))
+		}
+	}
+
+	getWirelessControlEnableConfig()
+	getNeedXrandrQConfig()
+
+	keybindingDS.InitSignalExt(m.systemSigLoop, true)
+	// 监听dsg配置变化
+	_, err = keybindingDS.ConnectValueChanged(func(key string) {
+		switch key {
+		case DSettingsKeyWirelessControlEnable:
+			getWirelessControlEnableConfig()
+		case DSettingsKeyNeedXrandrQDevices:
+			getNeedXrandrQConfig()
+		}
+	})
+	if err != nil {
+		logger.Warning(err)
 	}
 }
 
@@ -469,49 +519,6 @@ func (m *Manager) listenGlobalAccel(sessionBus *dbus.Conn) error {
 		}
 	})
 
-	//+ 监控鼠标移动事件
-	err = sessionBus.Object("com.deepin.daemon.KWayland",
-		"/com/deepin/daemon/KWayland/Output").AddMatchSignal("com.deepin.daemon.KWayland.Output", "CursorMove").Err
-	if err != nil {
-		logger.Warning(err)
-		return err
-	}
-	m.sessionSigLoop.AddHandler(&dbusutil.SignalRule{
-		Name: "com.deepin.daemon.KWayland.Output.CursorMove",
-	}, func(sig *dbus.Signal) {
-		if len(sig.Body) > 1 {
-			if m.dpmsIsOff {
-				err := exec.Command("dde_wldpms", "-s", "On").Run()
-				if err != nil {
-					logger.Warningf("failed to exec dde_wldpms: %s", err)
-				} else {
-					m.dpmsIsOff = false
-				}
-			}
-		}
-	})
-
-	//+ 监控鼠标按下事件
-	err = sessionBus.Object("com.deepin.daemon.KWayland",
-		"/com/deepin/daemon/KWayland/Output").AddMatchSignal("com.deepin.daemon.KWayland.Output", "ButtonPress").Err
-	if err != nil {
-		logger.Warning(err)
-		return err
-	}
-	m.sessionSigLoop.AddHandler(&dbusutil.SignalRule{
-		Name: "com.deepin.daemon.KWayland.Output.ButtonPress",
-	}, func(sig *dbus.Signal) {
-		if len(sig.Body) > 1 {
-			if m.dpmsIsOff {
-				err := exec.Command("dde_wldpms", "-s", "On").Run()
-				if err != nil {
-					logger.Warningf("failed to exec dde_wldpms: %s", err)
-				} else {
-					m.dpmsIsOff = false
-				}
-			}
-		}
-	})
 	return nil
 }
 
@@ -528,60 +535,15 @@ func (m *Manager) listenKeyboardEvent(systemBus *dbus.Conn) error {
 		if len(sig.Body) > 1 {
 			key := sig.Body[0].(uint32)
 			value := sig.Body[1].(uint32)
-			//+ 短按电源键同时出发kwin快捷键逻辑和libinput逻辑有冲突，先屏蔽
-			if m.dpmsIsOff && value == 1 && key != 116 {
-				logger.Debug("Keyboard:", key, value)
-				err := exec.Command("dde_wldpms", "-s", "On").Run()
-				if err != nil {
-					logger.Warningf("failed to exec dde_wldpms: %s", err)
-				} else {
-					m.dpmsIsOff = false
-				}
-			}
 
-			if _useWayland {
-				if key == CapslockKey && value == KeyPress {
-					m.handleKeyEventByWayland("capslock")
-				} else if key == NumlockKey && value == KeyPress {
-					m.handleKeyEventByWayland("numlock")
-				}
+			if key == CapslockKey && value == KeyPress {
+				m.handleKeyEventByWayland("capslock")
+			} else if key == NumlockKey && value == KeyPress {
+				m.handleKeyEventByWayland("numlock")
 			}
 		}
 	})
 
-	// 监听dsg配置变化
-	m.systemSigLoop.AddHandler(&dbusutil.SignalRule{
-		Name: "org.desktopspec.ConfigManager.Manager.valueChanged",
-	}, func(sig *dbus.Signal) {
-		if strings.Contains(string(sig.Name), "org.desktopspec.ConfigManager.Manager.valueChanged") {
-			m.wifiControlEnable = m.getwirelessControlEnable()
-		}
-	})
-	return nil
-}
-
-func (m *Manager) listenMouseEvent(systemBus *dbus.Conn) error {
-	err := systemBus.Object("com.deepin.daemon.Gesture",
-		"/com/deepin/daemon/Gesture").AddMatchSignal("com.deepin.daemon.Gesture", "MouseEvent").Err
-	if err != nil {
-		logger.Warning(err)
-		return err
-	}
-	m.systemSigLoop.AddHandler(&dbusutil.SignalRule{
-		Name: "com.deepin.daemon.Gesture.MouseEvent",
-	}, func(sig *dbus.Signal) {
-		if len(sig.Body) > 1 {
-			if m.dpmsIsOff {
-				logger.Debug("MouseEvent: dpms on")
-				err := exec.Command("dde_wldpms", "-s", "On").Run()
-				if err != nil {
-					logger.Warningf("failed to exec dde_wldpms: %s", err)
-				} else {
-					m.dpmsIsOff = false
-				}
-			}
-		}
-	})
 	return nil
 }
 
@@ -1129,18 +1091,3 @@ func (m *Manager) eliminateKeystrokeConflict() {
 	m.shortcutManager.ConflictingKeystrokes = nil
 	m.shortcutManager.EliminateConflictDone = true
 }
-
-func (m *Manager) getwirelessControlEnable() bool {
-	systemConn, err := dbus.SystemBus()
-	if err != nil {
-		return true
-	}
-	systemConnObj := systemConn.Object("org.desktopspec.ConfigManager", m.configManagerPath)
-	var value bool
-	err = systemConnObj.Call("org.desktopspec.ConfigManager.Manager.value", 0, "wirelessControlEnable").Store(&value)
-	if err != nil {
-		logger.Warning(err)
-		return false
-	}
-	return value
-}
