@@ -349,7 +349,7 @@ func (sh *stateHandler) watch(path dbus.ObjectPath) {
 						msg = fmt.Sprintf(Tr("Unable to connect %q, please check your router or net cable."), dsi.aconnId)
 					}
 				case nm.NM_DEVICE_STATE_REASON_SUPPLICANT_DISCONNECT:
-					if oldState == nm.NM_DEVICE_STATE_CONFIG && newState == nm.NM_DEVICE_STATE_NEED_AUTH {
+					if (oldState == nm.NM_DEVICE_STATE_CONFIG || oldState == nm.NM_DEVICE_STATE_ACTIVATED) && newState == nm.NM_DEVICE_STATE_NEED_AUTH {
 						msg = fmt.Sprintf(Tr("Connection failed, unable to connect %q, wrong password"), dsi.aconnId)
 					}
 				case CUSTOM_NM_DEVICE_STATE_REASON_CABLE_UNPLUGGED: //disconnected due to cable unplugged
