@@ -14,6 +14,7 @@ import (
 
 	"github.com/godbus/dbus"
 	bluez "github.com/linuxdeepin/go-dbus-factory/org.bluez"
+	ConfigManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
 	ofdbus "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.dbus"
 	login1 "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.login1"
 	"github.com/linuxdeepin/go-lib/dbusutil"
@@ -50,6 +51,12 @@ const (
 	devIconInputMouse      = "input-mouse"
 )
 
+const (
+	dsettingsAppID             = "org.deepin.dde.daemon"
+	dsettingsBluetoothName     = "org.deepin.dde.daemon.bluetooth"
+	dsettingsAutoPairEnableKey = "autoPairEnable"
+)
+
 //go:generate dbusutil-gen -type SysBluetooth bluetooth.go
 //go:generate dbusutil-gen em -type SysBluetooth,agent
 
@@ -84,11 +91,12 @@ type SysBluetooth struct {
 	// 当发起设备连接成功后，应该把连接的设备添加进设备列表
 	connectedDevices map[dbus.ObjectPath][]*device
 	connectedMu      sync.RWMutex
-	//设备被清空后需要连接的设备路径
+	// 设备被清空后需要连接的设备路径
 	prepareToConnectedDevice dbus.ObjectPath
 	prepareToConnectedMu     sync.Mutex
 	// 升级后第一次进系统，此时需要根据之前有蓝牙连接时，打开蓝牙开关
 	needFixBtPoweredStatus bool
+	canAutoPair            func() bool
 
 	// nolint
 	signals *struct {
@@ -206,6 +214,31 @@ func (b *SysBluetooth) init() {
 		logger.Warning(err)
 	}
 
+	ds := ConfigManager.NewConfigManager(b.sigLoop.Conn())
+
+	dsBluetoothPath, err := ds.AcquireManager(0, dsettingsAppID, dsettingsBluetoothName, "")
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	dsBluetooth, err := ConfigManager.NewManager(b.sigLoop.Conn(), dsBluetoothPath)
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	b.canAutoPair = func() bool {
+		v, err := dsBluetooth.Value(0, dsettingsAutoPairEnableKey)
+		if err != nil {
+			logger.Warning(err)
+			return true
+		}
+		return v.Value().(bool)
+	}
+
+	logger.Info("====== dsg autoPairEnable is ======", b.canAutoPair())
+
 	b.loginManager.InitSignalExt(b.sigLoop, true)
 	_, err = b.loginManager.ConnectSessionNew(b.handleSessionNew)
 
@@ -295,12 +328,12 @@ func (b *SysBluetooth) handlePrepareForSleep(beforeSleep bool) {
 	}
 	logger.Debug("Wakeup from sleep, will set adapter and try connect device")
 	time.AfterFunc(time.Second*3, func() {
-		//for _, adapter := range b.adapters {
+		// for _, adapter := range b.adapters {
 		//	if !adapter.Powered {
 		//		continue
 		//	}
 		//	//_ = adapter.core.Adapter().Discoverable().Set(0, b.config.Discoverable)
-		//}
+		// }
 		b.tryConnectPairedDevices("")
 	})
 }
@@ -811,6 +844,15 @@ func (b *SysBluetooth) getDevices(adapterPath dbus.ObjectPath) []*device {
 }
 
 func (b *SysBluetooth) tryConnectPairedDevices(adapterPath dbus.ObjectPath) {
+	if b.canAutoPair != nil {
+		if !b.canAutoPair() {
+			logger.Info("can't auto pair beacuse autoPairEnable key is unable")
+			return
+		}
+	} else {
+		return
+	}
+
 	inputOnly := true
 	// 自动连接时长
 	defaultConnectDuration := 2 * time.Minute
