@@ -6,6 +6,7 @@ package inputdevices
 
 import (
 	"github.com/linuxdeepin/dde-daemon/loader"
+	"github.com/linuxdeepin/go-lib/dbusutil"
 	"github.com/linuxdeepin/go-lib/log"
 )
 
@@ -47,6 +48,7 @@ func (d *daemon) Start() error {
 	service := loader.GetService()
 	d.inputdevices.service = service
 	d.inputdevices.init()
+	d.inputdevices.systemSigLoop = dbusutil.NewSignalLoop(service.Conn(), 5)
 
 	err := service.Export(dbusPath, d.inputdevices)
 	if err != nil {
