@@ -135,6 +135,7 @@ type device struct {
 	iface    string
 	nmDevice networkmanager.Device
 	type0    uint32
+	count    int
 }
 
 func (n *Network) getSysBus() *dbus.Conn {
@@ -476,10 +477,51 @@ func (n *Network) disableDevice(d *device) error {
 		return err
 	}
 
+	//TODO:
+	//cause of nm'bug, sometimes accessapoints list is nil
+	//so add a judge in system network, if get nil in GetAllAccessPoints func, set wirelessEnable down.
 	state, err := d.nmDevice.Device().State().Get(0)
 	if err != nil {
 		return err
 	}
+	oldWirelessEnabled, err := n.nmManager.WirelessEnabled().Get(0)
+	if err != nil {
+		return err
+	}
+	if d.type0 == nm.NM_DEVICE_TYPE_WIFI && state > nm.NM_DEVICE_STATE_UNAVAILABLE {
+		mode, err := d.nmDevice.Wireless().Mode().Get(0)
+		if err != nil {
+			logger.Warning(err)
+		}
+
+		if mode != nm.NM_802_11_MODE_AP {
+			accessPointsList, err := d.nmDevice.Wireless().GetAllAccessPoints(0)
+			if err != nil {
+				logger.Warning("GetAllAccessPoints in system network ", err)
+			}
+
+			if len(accessPointsList) > 0 {
+				d.count = 0
+				logger.Debug("have aplist existed!!!")
+			} else if d.count++; d.count > 2 {
+				d.count = 0
+				logger.Info("try to set wireless-enabled, because ap list is empty")
+				err = n.nmManager.WirelessEnabled().Set(0, false)
+				if err != nil {
+					logger.Debug("set WirelessEnabled in system network failed ", err)
+					return err
+				}
+				if oldWirelessEnabled {
+					err = n.nmManager.WirelessEnabled().Set(0, true)
+					if err != nil {
+						logger.Debug("set WirelessEnabled in system network failed ", err)
+						return err
+					}
+				}
+				return nil
+			}
+		}
+	}
 
 	if state >= nm.NM_DEVICE_STATE_PREPARE &&
 		state <= nm.NM_DEVICE_STATE_ACTIVATED {
