@@ -11,10 +11,11 @@ import (
 	"os/exec"
 	"path/filepath"
 	"regexp"
-	"strings"
 	"runtime"
-	"github.com/linuxdeepin/go-lib/strv"
+	"strings"
+
 	"github.com/linuxdeepin/go-lib/dbusutil"
+	"github.com/linuxdeepin/go-lib/strv"
 	dutils "github.com/linuxdeepin/go-lib/utils"
 )
 
@@ -36,8 +37,8 @@ type CpuHandler struct {
 type CpuHandlers []CpuHandler
 
 //内核文档：https://docs.kernel.org/admin-guide/pm/cpufreq.html#generic-scaling-governors
-var _scalingAvailableGovernors = []string {"performance", "powersave", "userspace", "ondemand", "conservative", "schedutil"}
-var _scalingBalanceAvailableGovernors = []string {"ondemand", "conservative", "schedutil", "performance"}
+var _scalingAvailableGovernors = []string{"performance", "powersave", "userspace", "ondemand", "conservative", "schedutil"}
+var _scalingBalanceAvailableGovernors = []string{"ondemand", "conservative", "schedutil", "performance"}
 var _supportGovernors []string
 var _localAvailableGovernors []string
 var _supportNormalBalanceArch = []string{"amd64", "x86_64", "amd", "x86", "386"}
@@ -90,8 +91,7 @@ func getIsBalanceSupported() bool {
 }
 
 func getIsHighPerformanceSupported() bool {
-	cpus := CpuHandlers{}
-	return  cpus.IsBoostFileExist() && strv.Strv(getSupportGovernors()).Contains("performance")
+	return strv.Strv(getSupportGovernors()).Contains("performance")
 }
 
 func getIsPowerSaveSupported() bool {
@@ -102,15 +102,15 @@ func isSystemSupportMode(mode string) bool {
 	return strv.Strv(_scalingBalanceAvailableGovernors).Contains(mode) && strv.Strv(_supportGovernors).Contains(mode)
 }
 
-func trySetBalanceCpuGovernor(balanceScalingGovernor string) (error, string) {
-	if "" == balanceScalingGovernor {
-		return nil, ""
+func trySetBalanceCpuGovernor(balanceScalingGovernor string) (string, error) {
+	if balanceScalingGovernor == "" {
+		return "", nil
 	}
 
 	// dconfig设置的模式如果不是平衡模式类型，则不进行设置
 	if !strv.Strv(getScalingBalanceAvailableGovernors()).Contains(balanceScalingGovernor) {
 		logger.Warningf("[trySetBalanceCpuGovernor] The governor is invalid. %s ", balanceScalingGovernor)
-		return dbusutil.ToError(fmt.Errorf(" The Governor is invalid. Please use performance, powersave, userspace, ondemand, conservative or schedutil. current value : %s", balanceScalingGovernor)), ""
+		return "", dbusutil.ToError(fmt.Errorf(" The Governor is invalid. Please use performance, powersave, userspace, ondemand, conservative or schedutil. current value : %s", balanceScalingGovernor))
 	}
 
 	// 系统支持的模式不包含设置的平衡模式，则按照产品优先级设置平衡模式 : ondemand > conservative > schedutil > performance
@@ -126,7 +126,7 @@ func trySetBalanceCpuGovernor(balanceScalingGovernor string) (error, string) {
 	}
 
 	logger.Info("[trySetBalanceCpuGovernor] balanceScalingGovernor : ", balanceScalingGovernor)
-	return nil, balanceScalingGovernor
+	return balanceScalingGovernor, nil
 }
 
 // true : 平衡模式使用 ondemand > conservative > schedutil > performance
@@ -242,7 +242,7 @@ func (cpus *CpuHandlers) getAvailableGovernors() (ret string, err error) {
 		data, err := ioutil.ReadFile(filepath.Join(cpu.path, globalAvailableGovernorFileName))
 		if err != nil {
 			logger.Warning(err)
-			return  ret, err
+			return ret, err
 		}
 		path := string(data)
 		if ret != path {
@@ -276,7 +276,7 @@ func (cpus *CpuHandlers) getCpuGovernorPath() string {
 		return ""
 	}
 	path := filepath.Join((*cpus)[0].path, globalGovernorFileName)
-	if "" == path {
+	if path == "" {
 		path = globalDefaultPath
 	}
 
@@ -287,30 +287,27 @@ func (cpus *CpuHandlers) getCpuGovernorPath() string {
 	return path
 }
 
-// 通过写文件的返回情况，获取非scaling_available_governors的值是否支持
-func (cpus *CpuHandlers) tryWriteGovernor(lines []string) []string {
+// 通过写文件的返回情况，获取list的值是否支持
+func (cpus *CpuHandlers) tryWriteGovernor(governorSlice strv.Strv) strv.Strv {
 	path := cpus.getCpuGovernorPath()
-	if "" == path {
+	if path == "" {
 		return nil
 	}
 
+	ret := strv.Strv{}
+
 	//获取当前系统的governor值
 	oldGovernor, err := ioutil.ReadFile(path)
 	if err != nil {
-		return lines
+		return ret
 	}
 	logger.Infof(" [tryWriteGovernor] Test Path : %s.", path)
-	// 遍历6个内核支持的数据，以及系统支持的数据
-	// 通过是否能写入文件判断不包含在supportGovernors的值是否支持设置
-	for _, value := range getScalingAvailableGovernors() {
-		if !strv.Strv(lines).Contains(value) {
-			err = ioutil.WriteFile(path, []byte(value), 0644)
-			logger.Infof(" Not contain in supportGovernors. Governor : %s.", value)
-			if err != nil {
-				logger.Infof(" Can't use the governor : %s. err : %s", value, err)
-			} else {
-				lines = append(lines, value)
-			}
+	for _, v := range governorSlice {
+		err = ioutil.WriteFile(path, []byte(v), 0644)
+		if err != nil {
+			logger.Infof(" Can't use the governor : %s. err : %s", v, err)
+		} else {
+			ret, _ = ret.Add(v)
 		}
 	}
 	//将当前系统原始的governor值设置回去
@@ -318,7 +315,7 @@ func (cpus *CpuHandlers) tryWriteGovernor(lines []string) []string {
 	if err != nil {
 		logger.Warning(err)
 	}
-	return lines
+	return ret
 }
 
 func (cpus *CpuHandlers) SetGovernor(governor string) error {
@@ -352,3 +349,29 @@ func (cpus *CpuHandlers) GetBoostEnabled() (bool, error) {
 	data, err := ioutil.ReadFile(globalBoostFilePath)
 	return strings.TrimSpace(string(data)) == "0", err
 }
+
+func findFile(root string, targetFile string) (string, error) {
+	var result string
+	err := filepath.Walk(root, func(path string, info os.FileInfo, err error) error {
+		if err != nil {
+			return err
+		}
+
+		if !info.IsDir() && info.Name() == targetFile {
+			result = path
+			return filepath.SkipDir
+		}
+
+		return nil
+	})
+
+	if err != nil {
+		return "", err
+	}
+
+	if result == "" {
+		return "", fmt.Errorf("file '%s' not found in directory '%s'", targetFile, root)
+	}
+
+	return result, nil
+}
