@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package power
 
@@ -125,11 +110,42 @@ func Test_getSupportGovernors(t *testing.T) {
 	assert.Equal(t, len(cpuGovernors), 0)
 }
 
+func Test_getLocalAvailableGovernors(t *testing.T) {
+	cpuGovernors := getLocalAvailableGovernors()
+	assert.NotEqual(t, len(cpuGovernors), 10)
+}
+
+func Test_isSystemSupportMode(t *testing.T) {
+	assert.Equal(t, isSystemSupportMode("powersave"), false)
+}
+
+func Test_setLocalAvailableGovernors(t *testing.T) {
+	var governors []string = []string{"aaaa", "bbbb", "cccc"}
+	setLocalAvailableGovernors(governors)
+	cpuGovernors := getLocalAvailableGovernors()
+	assert.Equal(t, len(cpuGovernors), 3)
+	assert.Equal(t, cpuGovernors[0], governors[0])
+	assert.Equal(t, cpuGovernors[1], governors[1])
+	assert.Equal(t, cpuGovernors[2], governors[2])
+}
+
 func Test_setSupportGovernors(t *testing.T) {
 	var lines = []string {"1", "2", "3"}
 	assert.NotEqual(t, len(setSupportGovernors(lines)), 10)
 }
 
+func Test_getAvailableGovernors(t *testing.T) {
+	cpus := CpuHandlers{}
+	govs, _ := cpus.getAvailableGovernors()
+	assert.NotEqual(t, govs, "/a/b/c/d")
+}
+
+func Test_getAvailableArrGovernors(t *testing.T) {
+	cpus := CpuHandlers{}
+	govs := cpus.getAvailableArrGovernors()
+	assert.NotEqual(t, len(govs), 10)
+}
+
 func Test_trySetBalanceCpuGovernor(t *testing.T)  {
 	err, target := trySetBalanceCpuGovernor("powersave")
 	assert.NotEqual(t, err, nil)
