@@ -10,25 +10,46 @@ import (
 	"io/ioutil"
 	"os"
 	"path/filepath"
+	"regexp"
+	"strings"
 	"sync"
 	"time"
 
 	dbus "github.com/godbus/dbus"
 	"github.com/linuxdeepin/dde-api/powersupply"
 	"github.com/linuxdeepin/dde-api/powersupply/battery"
+	"github.com/linuxdeepin/dde-daemon/common/cpuinfo"
+	ConfigManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
 	gudev "github.com/linuxdeepin/go-gir/gudev-1.0"
 	"github.com/linuxdeepin/go-lib/arch"
 	"github.com/linuxdeepin/go-lib/dbusutil"
 	"github.com/linuxdeepin/go-lib/strv"
+	"github.com/linuxdeepin/go-lib/utils"
 )
 
 var noUEvent bool
 
 const (
-	configManagerId = "org.desktopspec.ConfigManager"
-	_configHwSystem = "/usr/share/uos-hw-config"
+	configManagerId                   = "org.desktopspec.ConfigManager"
+	_configHwSystem                   = "/usr/share/uos-hw-config"
+	configDefaultGovFilePattern       = `config-[0-9\.]+-.*-desktop`
+	configDefaultGovContentDDEPattern = `CONFIG_CPU_FREQ_DEFAULT_GOV_DDE_(\w+)`
+	configDefaultGovContentPattern    = `CONFIG_CPU_FREQ_DEFAULT_GOV_(\w+)`
 )
 
+const (
+	dsettingsAppID                 = "org.deepin.dde.daemon"
+	dsettingsPowerName             = "org.deepin.dde.daemon.power"
+	dsettingsSpecialCpuModeJson    = "specialCpuModeJson"
+	dsettingsBalanceCpuGovernor    = "BalanceCpuGovernor"
+	dsettingsIsFirstGetCpuGovernor = "isFirstGetCpuGovernor"
+)
+
+type supportMode struct {
+	Balance    bool `json:"balance"`
+	Performace bool `json:"performace"`
+	PowerSave  bool `json:"powersave"`
+}
 
 func init() {
 	if arch.Get() == arch.Sunway {
@@ -99,12 +120,15 @@ type Manager struct {
 	IsPowerSaveSupported bool
 
 	// 性能模式-平衡模式dsg
-	balanceScalingGovernor     string
-	configManagerPath          dbus.ObjectPath
+	balanceScalingGovernor string
+	configManagerPath      dbus.ObjectPath
 
 	// 当前模式
 	Mode string
 
+	// Special Cpu suppoert mode
+	specialCpuMode *supportMode
+
 	// nolint
 	signals *struct {
 		BatteryDisplayUpdate struct {
@@ -247,6 +271,51 @@ func (m *Manager) init() error {
 	return nil
 }
 
+func (m *Manager) initSpecialCpuMode() {
+	// 获取cpu Hardware
+	cpuinfo, err := cpuinfo.ReadCPUInfo("/proc/cpuinfo")
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	// dsg 配置
+	ds := ConfigManager.NewConfigManager(m.systemSigLoop.Conn())
+	dsPowerPath, err := ds.AcquireManager(0, dsettingsAppID, dsettingsPowerName, "")
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+	dsPower, err := ConfigManager.NewManager(m.systemSigLoop.Conn(), dsPowerPath)
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	getSpecialCpuMode := func() {
+		data, err := dsPower.Value(0, dsettingsSpecialCpuModeJson)
+		if err != nil {
+			logger.Warning(err)
+			return
+		}
+		str := data.Value().(string)
+
+		modeMap := make(map[string]*supportMode)
+		if err := json.Unmarshal([]byte(str), &modeMap); err != nil {
+			logger.Warning(err)
+		}
+		for k, v := range modeMap {
+			if strings.HasPrefix(cpuinfo.Hardware, k) {
+				logger.Info("use special cpu mode", v)
+				m.specialCpuMode = v
+				return
+			}
+		}
+	}
+
+	getSpecialCpuMode()
+}
+
 func (m *Manager) refreshSystemPowerPerformance() { // 获取系统支持的性能模式
 	systemBus, err := dbus.SystemBus()
 	if err != nil {
@@ -256,101 +325,65 @@ func (m *Manager) refreshSystemPowerPerformance() { // 获取系统支持的性
 	m.initDsgConfig(systemBus)
 	m.systemSigLoop.Start()
 
+	m.initSpecialCpuMode()
+
 	path := m.cpus.getCpuGovernorPath()
-	if "" == path {
+	if path == "" {
 		m.IsHighPerformanceSupported = false
 		m.IsBalanceSupported = false
 		m.IsPowerSaveSupported = false
 		return
 	}
 
-	dsgCpuGovernor := interfaceToString(m.getDsgData("BalanceCpuGovernor"))
-	availableArrGovernors := m.cpus.getAvailableArrGovernors()
+	re := regexp.MustCompile(configDefaultGovFilePattern)
+	if result, err := utils.FindFileInDirRegexp("/boot/", re); err != nil {
+		logger.Warning(err)
+	} else if len(result) > 0 {
+		re = regexp.MustCompile(configDefaultGovContentDDEPattern)
+		_, matches, err := utils.FindContentInFileRegexp(result[0], re)
+		if err != nil {
+			logger.Warning(err)
+			re = regexp.MustCompile(configDefaultGovContentPattern)
+			_, matches, err = utils.FindContentInFileRegexp(result[0], re)
+			if err != nil {
+				logger.Warning(err)
+			}
+		}
+		if len(matches) > 1 {
+			m.balanceScalingGovernor = strings.ToLower(matches[1])
+		}
+	}
 
-	setUseNormalBalance(useNormalBalance())
-	//  如果当前是 平衡模式, 且不走正常平衡模式，且CpuGovernor不是performance, 则需要将m.CpuGovernor设置为performance
-	if m.Mode == "balance" && !getUseNormalBalance() && m.CpuGovernor != "performance" {
-		err := m.doSetCpuGovernor("performance")
+	if m.balanceScalingGovernor == "" {
+		logger.Warning("can't find balance scaling governor use ondemand")
+		m.balanceScalingGovernor = "ondemand"
+	}
+
+	if m.specialCpuMode != nil {
+		m.IsBalanceSupported = m.specialCpuMode.Balance
+		m.IsHighPerformanceSupported = m.specialCpuMode.Performace
+		m.IsPowerSaveSupported = m.specialCpuMode.PowerSave
+	} else {
+		logger.Info("check available governor")
+		m.IsBalanceSupported = true
+		ret := m.cpus.tryWriteGovernor(strv.Strv{"performance", "powersave"})
+		if ret.Contains("performance") {
+			m.IsHighPerformanceSupported = true
+		}
+		if ret.Contains("powersave") {
+			m.IsPowerSaveSupported = true
+		}
+	}
+
+	if m.cpus.IsBoostFileExist() {
+		logger.Info("default enable boost")
+		err = m.doSetCpuBoost(true)
 		if err != nil {
 			logger.Warning(err)
 		}
 	}
 
-	// 重启会进去，手动修改了dconfig的值才会进入else
-	if interfaceToBool(m.getDsgData("isFirstGetCpuGovernor")) {
-		if len(*m.cpus) <= 0 {
-			return
-		}
-
-		// 全部模式都支持的时候,不需要进行写入文件验证
-		if len(availableArrGovernors) != 6 {
-			availableArrGovernors = m.cpus.tryWriteGovernor(availableArrGovernors)
-		}
-		logger.Info(" First. available cpuGovernors : ", availableArrGovernors)
-		m.setDsgData("supportCpuGovernors", setSupportGovernors(availableArrGovernors))
-		setLocalAvailableGovernors(availableArrGovernors)
-
-		err, targetGovernor := trySetBalanceCpuGovernor(dsgCpuGovernor)
-		if err != nil {
-			logger.Warning(err)
-		} else {
-			if dsgCpuGovernor != targetGovernor && targetGovernor != "" {
-				m.setDsgData("BalanceCpuGovernor", targetGovernor)
-				logger.Info(" DConfig BalanceCpuGovernor not support. Set Governor : ", targetGovernor)
-			}
-		}
-	} else {
-		supportCpuGovernors := m.getDsgData("supportCpuGovernors")
-		cpuGovernors := interfaceToArrayString(supportCpuGovernors)
-		logger.Info(" dsg translate to Arr cpuGovernors : ", cpuGovernors)
-
-		supportGovernors := make([]string, len(cpuGovernors))
-		for i, v := range cpuGovernors {
-			supportGovernors[i] = v.(string)
-		}
-		setSupportGovernors(supportGovernors)
-		setLocalAvailableGovernors(availableArrGovernors)
-	}
-
-	m.IsBalanceSupported = getIsBalanceSupported()
-	m.IsHighPerformanceSupported = getIsHighPerformanceSupported()
-	m.IsPowerSaveSupported = getIsPowerSaveSupported()
-
-	if strv.Strv(getSupportGovernors()).Contains(dsgCpuGovernor) {
-		m.balanceScalingGovernor = dsgCpuGovernor
-	} else {
-		_, m.balanceScalingGovernor = trySetBalanceCpuGovernor(dsgCpuGovernor)
-	}
-
-	if !m.IsBalanceSupported {
-		logger.Info(" init end. getSupportGovernors ： ", getSupportGovernors(), " , m.balanceScalingGovernor : ", m.balanceScalingGovernor)
-		return
-	}
-
-	// 当支持平衡模式时, 错误将dsg配置设置成""或不支持的值, 则使用默认的平衡模式
-	if m.balanceScalingGovernor == "" || isSystemSupportMode(interfaceToString(m.getDsgData("BalanceCpuGovernor"))) {
-		availableArrGovsLen := len(availableArrGovernors)
-		if availableArrGovsLen <= 0 {
-			m.IsBalanceSupported = false
-			return
-		} else {
-			for i, v := range availableArrGovernors{
-				if strv.Strv(getScalingBalanceAvailableGovernors()).Contains(v) && !isSystemSupportMode(m.balanceScalingGovernor) {
-					m.balanceScalingGovernor = v
-					m.setDsgData("BalanceCpuGovernor", m.balanceScalingGovernor)
-					break
-				}
-
-				if i == availableArrGovsLen {
-					m.IsBalanceSupported = false
-					break
-				}
-			}
-
-		}
-	}
-
-	logger.Info(" init end. getSupportGovernors ： ", getSupportGovernors(), " , m.balanceScalingGovernor : ", m.balanceScalingGovernor)
+	logger.Info(" init end. m.balanceScalingGovernor : ", m.balanceScalingGovernor)
 }
 
 func (m *Manager) handleUEvent(client *gudev.Client, action string, device *gudev.Device) {
@@ -579,40 +612,16 @@ func (m *Manager) saveConfig() error {
 func (m *Manager) doSetMode(mode string) error {
 	var err error
 	switch mode {
-	case "balance": // governor=performance boost=false
-		if !m.IsBalanceSupported {
-			err = dbusutil.MakeErrorf(m, "PowerMode", "%q mode is not supported", mode)
-			break
-		}
+	case "balance":
+		logger.Info("[doSetMode] Set Governor, balanceScalingGovernor : ", m.balanceScalingGovernor)
 
 		m.setPropPowerSavingModeEnabled(false)
-		balanceScalingGovernor := m.balanceScalingGovernor
-		err, targetGovernor := trySetBalanceCpuGovernor(balanceScalingGovernor)
-		if  err != nil {
-			logger.Warning(err)
-			return err
-		}
-		dsgCpuGovernor := interfaceToString(m.getDsgData("BalanceCpuGovernor"))
-		logger.Infof(" [doSetMode] dsgCpuGovernor : %s, targetGovernor : %s, balanceScalingGovernor : %s ", dsgCpuGovernor, targetGovernor, balanceScalingGovernor)
-		if balanceScalingGovernor != targetGovernor {
-			balanceScalingGovernor = targetGovernor
-			logger.Info("[doSetMode] BalanceCpuGovernor not support. Set available governor : ", targetGovernor)
-		}
 
-		if balanceScalingGovernor != dsgCpuGovernor {
-			m.setDsgData("BalanceCpuGovernor", balanceScalingGovernor)
-		}
-
-		logger.Info("[doSetMode] Set Governor, balanceScalingGovernor : ", balanceScalingGovernor)
-		err = m.doSetCpuGovernor(balanceScalingGovernor)
+		err = m.doSetCpuGovernor(m.balanceScalingGovernor)
 		if err != nil {
 			logger.Warning(err)
 		}
-
-		if m.IsHighPerformanceSupported {
-			err = m.doSetCpuBoost(false)
-		}
-	case "powersave": // governor=powersave boost=false
+	case "powersave":
 		if !m.IsPowerSaveSupported {
 			err = dbusutil.MakeErrorf(m, "PowerMode", "%q mode is not supported", mode)
 			break
@@ -624,24 +633,18 @@ func (m *Manager) doSetMode(mode string) error {
 		if err != nil {
 			logger.Warning(err)
 		}
-
-		if m.IsHighPerformanceSupported {
-			err = m.doSetCpuBoost(false)
-		}
 	case "performance": // governor=performance boost=true
 		if !m.IsHighPerformanceSupported {
 			err = dbusutil.MakeErrorf(m, "PowerMode", "%q mode is not supported", mode)
 			break
 		}
+
 		m.setPropPowerSavingModeEnabled(false)
 
 		err = m.doSetCpuGovernor("performance")
 		if err != nil {
 			logger.Warning(err)
 		}
-
-		err = m.doSetCpuBoost(true)
-
 	default:
 		err = dbusutil.MakeErrorf(m, "PowerMode", "%q mode is not supported", mode)
 	}
@@ -654,6 +657,11 @@ func (m *Manager) doSetMode(mode string) error {
 }
 
 func (m *Manager) doSetCpuBoost(enabled bool) error {
+	if m.specialCpuMode != nil {
+		logger.Info("=== special cpu mode is on ===")
+		return nil
+	}
+
 	err := m.cpus.SetBoostEnabled(enabled)
 	if err == nil {
 		m.setPropCpuBoost(enabled)
@@ -662,10 +670,9 @@ func (m *Manager) doSetCpuBoost(enabled bool) error {
 }
 
 func (m *Manager) doSetCpuGovernor(governor string) error {
-	// 节能模式，高性能模式不受影响
-	if governor != "powersave" && governor != "performance" && !getUseNormalBalance() {
-		governor = "performance"
-		logger.Infof("[doSetCpuGovernor] change governor : %s to performance.", governor)
+	if m.specialCpuMode != nil {
+		logger.Info("=== special cpu mode is on ===")
+		return nil
 	}
 
 	err := m.cpus.SetGovernor(governor)
