@@ -5,7 +5,11 @@
 package systeminfo
 
 import (
+	"strings"
+
+	"github.com/jouyouyun/hardware/dmi"
 	"github.com/linuxdeepin/go-lib/log"
+
 	"github.com/linuxdeepin/dde-daemon/loader"
 )
 
@@ -40,23 +44,53 @@ func (m *Module) Start() error {
 		return err
 	}
 	go func() {
-		//init get memory
+		// init get memory
 		err = m.m.calculateMemoryViaLshw()
 		if err != nil {
 			logger.Warning(err)
 		}
-		//get system bit
+		// get system bit
 		systemType := 64
 		if "64" != m.m.systemBit() {
 			systemType = 32
 		}
-		//Get CPU MHZ
+		// Get CPU MHZ
 		currentSpeed, err1 := GetCurrentSpeed(systemType)
 		if err1 != nil {
 			logger.Warning(err1)
 			return
 		}
 		m.m.setPropCurrentSpeed(currentSpeed)
+		info, err := dmi.GetDMI()
+		if err != nil {
+			logger.Warning(err)
+		} else {
+			if info != nil {
+				m.m.setPropDMIInfo(*info)
+			}
+		}
+		// get system display driver info
+		classContent, err := getLshwData("display")
+		if err != nil {
+			logger.Warning(err)
+		} else {
+			var res []string
+			for _, item := range classContent {
+				res = append(res, item.Configuration.Driver)
+			}
+			m.m.setPropDisplayDriver(strings.Join(res, "&&"))
+		}
+		// get system video driver info
+		classContent, err = getLshwData("video")
+		if err != nil {
+			logger.Warning(err)
+		} else {
+			var res []string
+			for _, item := range classContent {
+				res = append(res, item.Configuration.Driver)
+			}
+			m.m.setPropVideoDriver(strings.Join(res, "&&"))
+		}
 	}()
 	return nil
 }
